@@ -34,11 +34,8 @@
 */
 
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
-#include <sys/types.h>
 
 #include "random.h"
 
