@@ -1,28 +1,25 @@
-/* 2003.05.02: Derived from libgcrypt-1.1.12 by Michael Buesch */
-
-/* blowfish.c  -  Blowfish encryption
- *	Copyright (C) 1998, 2001, 2002 Free Software Foundation, Inc.
- *
- * This file is part of Libgcrypt.
- *
- * Libgcrypt is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser general Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * Libgcrypt is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
- *
- * For a description of the algorithm, see:
- *   Bruce Schneier: Applied Cryptography. John Wiley & Sons, 1996.
- *   ISBN 0-471-11709-9. Pages 336 ff.
- */
+ /**************************************************************************
+ *   Implementation of the Blowfish chiper                                 *
+ *   Derived from Libgcrypt                                                * 
+ *                                                                         *
+ *   Copyright (C) 1998, 2001, 2002 Free Software Foundation, Inc.         *
+ *   Copyright (C) 2003 by Michael Buesch                                  *
+ *   Copyright (C) 2007 by Tarek Saidi <tarek.saidi@arcor.de>              *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; version 2 of the License.               *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ ***************************************************************************/
 
 /* Test values:
  * key	  "abcdefghijklmnopqrstuvwxyz";
@@ -31,8 +28,8 @@
  *
  */
 
-#include <string.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdlib>
 
 #include "blowfish.h"
 
@@ -230,7 +227,7 @@ static const uint32_t ps[BLOWFISH_ROUNDS + 2] = {
 };
 
 Blowfish::Blowfish()
-{	static bool mustSelfTest = false;
+{
 }
 
 void Blowfish::burn_stack(int bytes)
