@@ -1411,6 +1411,10 @@ The key is wrong or the file is damaged.</source>
         <source>Shift+Ctrl+F</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ctrl+M</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Error</source>
         <translation type="unfinished"></translation>
@@ -1841,6 +1845,10 @@ Do you want to save the changes?</source>
         <source>Sort groups</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Minimize Window</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ManageBookmarksDlg</name>
@@ -2069,6 +2077,10 @@ File is not readable.</source>
         <source>Minimize to tray instead of taskbar</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Minimize to tray when clicking the main window&apos;s close button</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Remember last opened file</source>
         <translation type="unfinished"></translation>
